@@ -3,7 +3,7 @@ package Prty;
 use strict;
 use warnings;
 
-our $VERSION = 1.097;
+our $VERSION = 1.098;
 
 =encoding utf8
 
@@ -32,7 +32,7 @@ L<Prty::Array> - Operationen auf Arrays
 
 =item *
 
-L<Prty::ClassConfig> - Definiere Information auf Klassenebene
+L<Prty::ClassConfig> - Verwalte Information auf Klassenebene
 
 =item *
 
@@ -364,7 +364,7 @@ L<Prty::PersistentHash> - Persistenter Hash
 
 =item *
 
-L<Prty::Pod> - POD-Generator
+L<Prty::Pod::Generator> - POD-Generator
 
 =item *
 
@@ -530,7 +530,7 @@ L<Prty::Unindent> - Entferne Einrückung von "Here Document" oder String-Literal
 
 =head1 VERSION
 
-1.097
+1.098
 
 =head1 AUTHOR
 
