@@ -4,16 +4,17 @@ use base qw/Prty::Hash/;
 use strict;
 use warnings;
 
-our $VERSION = 1.097;
+our $VERSION = 1.098;
 
 use Prty::Option;
 use Prty::Path;
 use Time::HiRes ();
 use Prty::Perl;
 use Prty::Hash;
+use Prty::DestinationTree;
 use Prty::Section::Parser;
 use Prty::Section::Object;
-use Prty::DestinationTree;
+use Prty::Terminal;
 use Prty::Formatter;
 use Prty::PersistentHash;
 
@@ -33,16 +34,56 @@ L<Prty::Hash>
 
     use Prty::ContentProcessor;
     
-    $cop = Prty::ContentProcessor->new('.mytool',-extension=>['.myt']);
+    $cop = Prty::ContentProcessor->new('.mytool');
     $cop->registerType('MyTool::Program::Shell','.mprg','[Program]',Language=>'Shell');
     ...
-    $cop->load(@paths)->generate->test;
+    $cop->load(@paths)->generate($dir)->test;
 
 =head1 DESCRIPTION
 
-Ein  Objekt der Klasse repräsentiert einen Prozessor für
-Abschnitts-Dateien, also Dateien, die von einem Abschnittsparser
-(s. Klasse Prty::Section::Parser) geparsed werden.
+Ein Objekt der Klasse repräsentiert einen Prozessor für
+Entitäts-Dateien. Die Dateien bestehen aus einer Folge von
+Abschnitten, die von einem Abschnitts-Parser (s. Klasse
+Prty::Section::Parser) geparsed und zu Abschnitts-Objekten
+instantiiert werden.
+
+Der Prozessor delegiert die Verarbeitung der Abschnitts-Objekte an
+die per registerType() registierten Entitäts-Klassen
+(Plugin-Schnittstelle). Diese bauen aus den Abschnitts-Objekten
+Entitäts-Strukturen auf, aus denen die Ausgabedateien generiert
+werden.
+
+=head2 Ausgaben
+
+Der Umfang an Ausgaben wird mit der Konstruktor-Option
+-verbosity=>$level eingestellt. Default ist 1.
+
+Die Methode msg() schreibt eine Ausgabe nach STDERR. Der erste
+Parameter gibt den Verbosity-Level an. Ist dieser größer als der
+eingestellte Verbosity-Level, unterbleibt die Ausgabe. Ist als
+Level 0 angegeben, erfolgt die Ausgabe I<immer>:
+
+    $cop->msg(0,...);
+
+=head1 EXAMPLES
+
+Alle Entitäts-Definitionen im Storage in eine einzige Datei $file
+schreiben (z.B. für Refactoring):
+
+    $cop->load->join($file);
+
+Alle Entitäts-Definitionen im Storage in eine Verzeichnisstruktur
+mit Wurzelverzeichnis $dir übertragen (z.B. um die
+Dateien einzeln zu editieren):
+
+    $cop->fetch->($dir);
+
+Alle Entitäten im Storage vom Typ $type auflisten:
+
+    $cop->load;
+    for my $ent ($cop->entities($type)) {
+        $cop->msg(0,$ent->name);
+    }
 
 =head1 METHODS
 
@@ -85,6 +126,10 @@ angegeben.
 
 Erzeuge und initialisiere Storage.
 
+=item -verbosity => 0|1|2 (Default: 1)
+
+Umfang der Laufzeit-Meldungen.
+
 =back
 
 =head4 Returns
@@ -103,10 +148,12 @@ sub new {
 
     my $extensions = [];
     my $init = 0;
+    my $verbosity = 1;
 
     Prty::Option->extract(\@_,
         -extensions=>\$extensions,
         -init=>\$init,
+        -verbosity=>\$verbosity,
     );
 
     # Prüfen, ob Storage-Verzeichnis existert
@@ -129,18 +176,21 @@ sub new {
 
     my $self = $class->SUPER::new(
         t0=>scalar Time::HiRes::gettimeofday,
+        verbosity=>$verbosity,
         storage=>$storage,
         baseExtensionA=>$extensions,
         pluginA=>[],
-        entityA=>[],
         fileA=>[],
         parsedSections=>0,
         parsedLines=>0,
         parsedChars=>0,
         parsedBytes=>0,
         # memoize
+        entityA=>undef,
+        entityTypeA=>undef,
         extensionRegex=>undef,
         stateDb=>undef,
+        typeH=>undef,
     );
 
     return $self;
@@ -155,6 +205,7 @@ sub new {
 =head4 Synopsis
 
     $cop->registerType($pluginClass,$extension,$sectionType,@keyVal);
+    $cop->registerType($pluginClass,$extension); # universelles Plugin
 
 =head4 Description
 
@@ -168,6 +219,14 @@ Die Plugin-Definition wird intern auf einem Hash-Objekt
 gespeichert, das vom ContentProcessor mit den instantiierten
 Entitten verknüpft wird.
 
+Ein I<Universelles Plugin> kann definiert werden, indem nur
+$pluginClass und $extension angegeben werden. An diese
+Plugin-Klasse werden alle (Haupt-)Abschnitts-Objekte delegiert, für
+die kein Plugin definiert ist. Logischerweise kann es
+höchstens ein Universelles Plugin geben. Für ein Universelles
+Plugin findet keine Attribut-Validierung in der der
+Basisklassenmethode create() statt.
+
 =head4 Arguments
 
 =over 4
@@ -218,37 +277,17 @@ sub registerType {
 
 =head2 Operationen
 
-=head3 load() - Lade Eingabe-Dateien
+=head3 commit() - Übertrage Veränderungen in den Storage
 
 =head4 Synopsis
 
-    $cop = $cop->load(@opt,@paths);
+    $cop = $cop->commit;
 
 =head4 Description
 
-Lade die Eingabe-Dateien der Pfade @paths.
-
-=head4 Arguments
-
-=over 4
-
-=item @paths
-
-Liste der Verzeichnisse und Dateien. Der Pfad '-' bedeutet STDIN.
-
-=back
-
-=head4 Options
-
-=over 4
-
-=item -commit => $bool (default: 0)
-
 Vergleiche die Entitäten gegen den Storage und übertrage die
-Veränderungen. Geänderte Entitäten werden in der in der Datenbank
-als geändert gekennzeichnet.
-
-=back
+Veränderungen dorthin. Geänderte Entitäten werden in der in der
+Datenbank als geändert gekennzeichnet.
 
 =head4 Returns
 
@@ -258,135 +297,40 @@ ContentProcessor-Objekt (für Method-Chaining)
 
 # -----------------------------------------------------------------------------
 
-sub load {
+sub commit {
     my $self = shift;
-    # @_: @opt,@paths
 
-    # Argumente und Optionen
+    $self->msg(1,'%T ==commit==');
 
-    my $commit = 0;
+    # Gleiche Eingabedateien mit Storage-Dateien ab
 
-    Prty::Option->extract(\@_,
-        -commit=>\$commit,
+    my $defDir = $self->storage('def');
+
+    my $dt = Prty::DestinationTree->new($defDir,
+        -quiet=>0,
+        -language=>'en',
+        -outHandle=>\*STDERR,
     );
-    my @paths = @_;
+    $dt->addDir($defDir);
 
-    # Ermittele die zu verarbeitenden Dateien
-    
-    printf STDERR "%.3f ==find==\n",
-        Time::HiRes::gettimeofday-$self->get('t0');
-        
-    my @files;
-    for my $path (@paths) {
-        if (-d $path) {
-            # Verzeichnis: nach Dateien durchsuchen
-
-            push @files,Prty::Path->find($path,
-                -type=>'f',
-                -pattern=>$self->extensionRegex,
-            );
-        }
-        else {
-            # Datei: direkt hinzufügen
-            push @files,$path;
-        }
-    }
-    
-    printf STDERR "%.3f ==parse==\n",
-        Time::HiRes::gettimeofday-$self->get('t0');
-
-    # Instantiiere Parser
-
-    my $par = Prty::Section::Parser->new(
-        encoding=>'utf-8',
-    );
-
-    # Parse Dateien zu Entitäten
-
-    my $entityA = $self->get('entityA');
-    for my $file (@files) {
-        $par->parse($file,sub {
-            my $sec = Prty::Section::Object->new(@_);
-
-            if ($sec->brackets eq '[]') {
-                # Wandele Abschnitts-Objekt in Entität
-    
-                my $plg = $self->plugin($sec);
-                if (!$plg) {
-                    # Fehler: Für jeden Haupt-Abschnitt muss ein
-                    # Plugin definiert worden sein
-    
-                    $sec->error(
-                        q{COP-00001: Missing plugin for main section},
-                         Section=>$sec->fullType,
-                    );
-                }
-                push @$entityA,$plg->class->create($sec,$self,$plg);
-            }
-            elsif (@$entityA) {
-                # Füge weiteren Abschnitt zu Entität hinzu
-    
-                my $ent = $entityA->[-1];
-                $ent->addSubSection($sec);
-                $ent->transferSource($sec);
-            }
-            else {
-                # Fehler: Erster Abschnitt ist kein []-Abschnitt
-    
-                $sec->error(
-                    q{COP-00002: First section must be a []-section},
-                     Section=>$sec->fullType,
-                );
-            }
-
-            # Abschnittsobjekt gegen unabsichtliche Erweiterungen sperren
-            $sec->lockKeys;
-
-            return;
-        });
-    }
-
-    # Statistische Daten sichern
-
-    $self->set(parsedSections=>$par->get('parsedSections'));
-    $self->set(parsedLines=>$par->get('parsedLines'));
-    $self->set(parsedChars=>$par->get('parsedChars'));
-    $self->set(parsedBytes=>$par->get('parsedBytes'));
-
-    if ($commit) {    
-        printf STDERR "%.3f ==commit==\n",
-            Time::HiRes::gettimeofday-$self->get('t0');
-
-        # Gleiche Eingabedateien mit Storage-Dateien ab
-
-        my $defDir = $self->storage('def');
-
-        my $dt = Prty::DestinationTree->new($defDir,
-            -quiet=>0,
-            -language=>'en',
-            -outHandle=>\*STDERR,
+    for my $ent (@{$self->entities}) {
+        $dt->addFile($ent->entityFile($defDir),$ent->sourceRef,
+            -encoding=>'utf-8',
+            -onUpdate=>sub {
+                $self->state($ent,1);
+            },
         );
-        $dt->addDir($defDir);
-
-        for my $ent (@$entityA) {
-            my $file = $defDir.'/'.$ent->entityId.'.'.$ent->plugin->extension;
-            $dt->addFile($file,$ent->sourceRef,
-                -encoding=>'utf-8',
-                -onUpdate=>sub {
-                    $self->state($ent,1);
-                },
-            );
-        }
-        $self->stateDb->sync;
-
-        # Lösche überzählige Storage-Dateien (nach Rückfrage)
-
-        $dt->cleanup(1,$self->getRef('t0'));
-        $dt->close;
     }
+    $self->stateDb->sync;
+
+    # Lösche überzählige Storage-Dateien (nach Rückfrage)
+
+    $dt->cleanup(1,$self->getRef('t0'));
+    $dt->close;
 
     return $self;
 }
+    
 
 # -----------------------------------------------------------------------------
 
@@ -413,8 +357,7 @@ sub generate {
     my ($self,$dir) = @_;
     # @_: @opt
 
-    printf STDERR "%.3f ==generate==\n",
-        Time::HiRes::gettimeofday-$self->get('t0');
+    $self->msg(1,'%T ==generate==');
 
     # Argumente und Optionen
 
@@ -433,8 +376,7 @@ sub generate {
     $dt->addDir($dir);
     $dt->addDir($pureDir);
 
-    my $entityA = $self->get('entityA');
-    for my $ent (@$entityA) {
+    for my $ent (@{$self->entities}) {
         my $codeWritten = 0;
         for my $fil ($ent->files) {
             my $written = $dt->addFile($dir.'/'.$fil->name,
@@ -476,6 +418,245 @@ sub generate {
 }
     
 
+# -----------------------------------------------------------------------------
+
+=head3 load() - Lade Entitäts-Definitionen
+
+=head4 Synopsis
+
+    $cop = $cop->load;
+    $cop = $cop->load(@paths);
+
+=head4 Description
+
+Lade die Entitäts-Dateien der Pfade @paths. Ist @path leer, also
+kein Path angegeben, werden die Entitäts-Dateien aus dem Storage
+geladen.
+
+Die Methode kann beliebig oft aufgerufen werden, aber nur der
+erste Aufruf lädt, alle weiteren Aufrufe sind Null-Operationen.
+
+=head4 Arguments
+
+=over 4
+
+=item @paths
+
+Liste der Verzeichnisse und Dateien. Pfad '-' bedeutet STDIN.
+
+=back
+
+=head4 Returns
+
+ContentProcessor-Objekt (für Method-Chaining)
+
+=cut
+
+# -----------------------------------------------------------------------------
+
+sub load {
+    my ($self,@paths) = @_;
+
+    $self->memoize('entityA',sub {
+        $self->msg(2,'%T ==find==');
+
+        if (!@paths) {
+            @paths = ($self->storage('def'));
+        }
+
+        # Ermittele die zu verarbeitenden Dateien
+
+        my @files;
+        for my $path (@paths) {
+            push @files,-d $path? $self->findFiles($path): $path;
+        }
+
+        my $n = scalar @files;
+        if ($n > 1) {
+            $self->msg(2,'Files: %N',$n);
+        }
+
+        $self->msg(2,'%T ==parse==');
+
+        # Instantiiere Parser
+
+        my $par = Prty::Section::Parser->new(
+            encoding=>'utf-8',
+        );
+
+        # Parse Dateien zu Entitäten
+
+        my @entities;
+        for my $file (@files) {
+            $par->parse($file,sub {
+                my $sec = Prty::Section::Object->new(@_);
+                # $sec->removeEofMarker;
+
+                if ($sec->brackets eq '[]') {
+                    # Wandele Abschnitts-Objekt in Entität
+
+                    my $plg = $self->plugin($sec);
+                    if (!$plg) {
+                        # Fehler: Für jeden Haupt-Abschnitt muss ein
+                        # Plugin definiert worden sein
+
+                        $sec->error(
+                            q{COP-00001: Missing plugin for section},
+                             Section=>$sec->fullType,
+                        );
+                    }
+                    push @entities,$plg->class->create($sec,$self,$plg);
+                }
+                elsif (@entities) {
+                    # Füge weiteren Abschnitt zu Entität hinzu
+
+                    my $ent = $entities[-1];
+                    $ent->addSubSection($sec);
+                    $ent->transferSource($sec);
+                }
+                else {
+                    # Fehler: Erster Abschnitt ist kein []-Abschnitt
+
+                    $sec->error(
+                        q{COP-00002: First section must be a []-section},
+                         Section=>$sec->fullType,
+                    );
+                }
+
+                # Abschnittsobjekt gegen unabsichtliche Erweiterungen sperren
+                $sec->lockKeys;
+
+                return;
+            });
+        }
+
+        # Statistische Daten sichern
+
+        $self->set(parsedSections=>$par->get('parsedSections'));
+        $self->set(parsedLines=>$par->get('parsedLines'));
+        $self->set(parsedChars=>$par->get('parsedChars'));
+        $self->set(parsedBytes=>$par->get('parsedBytes'));
+
+        return \@entities;
+    });
+    
+    return $self;
+}
+
+# -----------------------------------------------------------------------------
+
+=head3 fetch() - Erzeuge Verzeichnisstruktur mit Entitäts-Definitionen
+
+=head4 Synopsis
+
+    $cop = $cop->fetch($dir,$layout);
+
+=head4 Description
+
+Übertrage alle Entitäts-Definitionen in Verzeichnis $dir (oder
+STDOUT, s.u.) gemäß dem Layout $layout. Per Differenzbildung wird
+dabei ein konsistenter Stand hergestellt. Existiert Verzeichnis
+$dir nicht, wird es angelegt. Andernfalls wird eine Rückfrage
+gestellt, ob das Verzeichnis überschrieben werden soll (siehe
+auch Option --overwrite).
+
+Wird als Verzeichnis ein Bindestrich (-) angegeben, werden die Daten
+nach STDOUT geschrieben.
+
+Die Methode bezieht die zu schreibenden Dateien von der Methode
+L</fetchFiles>(), an die der Parameter $layout weiter gereicht
+wird. Die Methode kann in abgeleiteten Klassen überschrieben
+werden, um andere Strukturen zu generieren.
+
+=head4 Arguments
+
+=over 4
+
+=item $dir
+
+Verzeichnis, in das die Entitäts-Definitionen kopiert werden.
+
+=item $layout
+
+Bezeichnung für das Verzeichnis-Layout. Wird von der von
+fetchFiles() der Basisklasse nicht genutzt und daher hier nicht
+dokumentiert. Siehe Dokumentation bei den Subklassen.
+
+=back
+
+=head4 Options
+
+=over 4
+
+=item -overwrite => $bool (Default: 0)
+
+Stelle keine Rückfrage, wenn Verzeichnis $dir bereits existiert.
+
+=back
+
+=head4 Returns
+
+ContentProcessor-Objekt (für Method-Chaining)
+
+=cut
+
+# -----------------------------------------------------------------------------
+
+sub fetch {
+    my ($self,$dir,$layout) = @_;
+
+    $self->msg(2,'%T ==fetch==');
+
+    # Optionen
+
+    my $overwrite = 0;
+
+    Prty::Option->extract(\@_,
+        -overwrite=>\$overwrite,
+    );
+
+    if ($dir eq '-') {
+        for my $e ($self->fetchFiles($layout)) {
+            print ref $e->[1]? ${$e->[1]}: $e->[1];
+        }
+        return $self;
+    }
+    elsif (-d $dir && !$overwrite) {
+        my $answ = Prty::Terminal->askUser(
+            "Overwrite files in directory '$dir'?",
+            -values=>'y/n',
+            -default=>'y',
+            -outHandle=>\*STDERR,
+            -timer=>$self->getRef('t0'),
+        );
+        if ($answ ne 'y') {
+            return $self;
+        }
+    }
+    
+    my $dt = Prty::DestinationTree->new($dir,
+        # -files=>scalar $self->findFiles($dir),
+        -quiet=>0,
+        -language=>'en',
+        -outHandle=>\*STDERR,
+    );
+    $dt->addDir($dir);
+
+    for my $e ($self->fetchFiles($layout)) {
+        $dt->addFile("$dir/$e->[0]",$e->[1],
+            -encoding=>'utf-8',
+        );
+    }
+
+    # Lösche überzählige Storage-Dateien (nach Rückfrage)
+
+    $dt->cleanup(1,$self->getRef('t0'));
+    $dt->close;
+
+    return $self;
+}
+    
+
 # -----------------------------------------------------------------------------
 
 =head3 test() - Teste geänderten Code
@@ -495,14 +676,140 @@ ContentProcessor-Objekt (für Method-Chaining)
 sub test {
     my $self = shift;
 
-    printf STDERR "%.3f ==test==\n",
-        Time::HiRes::gettimeofday-$self->get('t0');
+    $self->msg(1,'%T ==test==');
     
     return $self;
 }
 
 # -----------------------------------------------------------------------------
 
+=head2 Entitäten
+
+=head3 entities() - Liefere Entities
+
+=head4 Synopsis
+
+    @entities | $entityA = $cop->entities;
+    @entities | $entityA = $cop->entities($type);
+
+=head4 Description
+
+Liefere die Liste aller geladenen Entities oder aller
+geladenen Entities vom Typ $type. Bei der Abfrage der Entities
+eines Typs werden die Entities nach Name sortiert geliefert.
+
+=head4 Arguments
+
+=over 4
+
+=item $type
+
+Abschnitts-Typ.
+
+=back
+
+=head4 Returns
+
+Liste von Entitäten. Im Skalarkontext eine Referenz auf die Liste.
+
+=cut
+
+# -----------------------------------------------------------------------------
+
+sub entities {
+    my ($self,$type) = @_;
+
+    if (!$type) {
+        my $entityA = $self->{'entityA'};
+        return wantarray? @$entityA: $entityA;
+    }
+
+    my $h = $self->memoize('typeH',sub {
+        my ($self,$key) = @_;
+
+        my $typeA = $self->entityTypes;
+    
+        # Hash mit allen Abschnittstypen aufbauen
+    
+        my %h;
+        for my $type (@$typeA) {
+            $h{$type} ||= [];
+        }
+
+        # Entitäten zuordnen
+    
+        for my $ent (@{$self->{'entityA'}}) {
+            push @{$h{$ent->type}},$ent;
+        }
+
+        # Entitäten nach Name sortieren
+    
+        for my $type (@$typeA) {
+            @{$h{$type}} = sort {$a->name cmp $b->name} @{$h{$type}};
+        }
+
+        return \%h;
+    });
+
+    my $a = $h->{$type} || $self->throw;    
+    return wantarray? @$a: $a;
+}
+
+# -----------------------------------------------------------------------------
+
+=head2 Dateien
+
+=head3 fetchFiles() - Liste der Dateien für fetch
+
+=head4 Synopsis
+
+    @files = $cop->fetchFiles;
+    @files = $cop->fetchFiles($layout);
+
+=head4 Description
+
+Liefere die Liste der Dateien, die von der Methode L</fetch>()
+geschrieben werden. Jede Datei wird durch ein zweielementiges
+Array repräsentiert, bestehend aus einem Datei-Pfad und dem
+Datei-Inhalt. Der Datei-Inhalt kann als String oder String-Referenz
+angegeben sein.
+
+Diese (Basisklassen-)Methode liefert für jede Entität die
+Datei-Definiton
+
+    [$ent->entityFile, $ent->sourceRef]
+
+Damit erzeugt die Methode fetch() die gleiche Struktur wie
+der ContentProcessor im Storage-Verzeichnis def.
+
+Die Methode kann in abgeleiteten Klassen überschrieben werden, um
+die Verzeichnisstruktur zu ändern und/oder den Inhalt der Dateien
+anders zusammenzustellen (z.B. mehrere Entity-Definitionen in
+einer Datei zusammenzufassen). In abgeleiteten Klassen können
+verschiedene Layouts können durch das Argument $layout
+unterschieden werden.
+
+=head4 Returns
+
+Array mit zweielementigen Arrays
+
+=cut
+
+# -----------------------------------------------------------------------------
+
+sub fetchFiles {
+    my ($self,$layout) = @_;
+
+    my @files;
+    for my $ent (@{$self->entities}) {
+        push @files,[$ent->entityFile,$ent->sourceRef];
+    }
+    
+    return @files;
+}
+
+# -----------------------------------------------------------------------------
+
 =head2 Statistik
 
 =head3 info() - Informationszeile
@@ -527,13 +834,12 @@ Zeichenkette
 sub info {
     my $self = shift;
 
-    my $entities = @{$self->get('entityA')};
-    my $files = @{$self->get('fileA')};
+    my $entityCount = @{$self->get('entityA')};
     
     return sprintf '%.3f sec; Entities: %s; Sections: %s; Lines: %s'.
             '; Bytes: %s; Chars: %s',
         Time::HiRes::gettimeofday-$self->get('t0'),
-        Prty::Formatter->readableNumber($entities,','),
+        Prty::Formatter->readableNumber($entityCount,','),
         Prty::Formatter->readableNumber($self->get('parsedSections'),','),
         Prty::Formatter->readableNumber($self->get('parsedLines'),','),
         Prty::Formatter->readableNumber($self->get('parsedBytes'),','),
@@ -544,6 +850,45 @@ sub info {
 
 =head2 Intern
 
+=head3 entityTypes() - Liste der Abschnitts-Typen
+
+=head4 Synopsis
+
+    @types | $typeA = $cop->entityTypes;
+
+=head4 Description
+
+Liefere die Liste der Abschnitts-Typen, die per registerType()
+registriert wurden.
+
+=head4 Returns
+
+Liste von Abschnitts-Typen. Im Skalarkontext eine Referenz auf die
+Liste.
+
+=cut
+
+# -----------------------------------------------------------------------------
+
+sub entityTypes {
+    my $self = shift;
+
+    my $a = $self->memoize('entityTypeA',sub {
+        my ($self,$key) = @_;
+
+        my %h;
+        for my $plg (@{$self->{'pluginA'}}) {
+            $h{$plg->sectionType}++;
+        }
+
+        return [sort keys %h];
+    });
+
+    return wantarray? @$a: $a;
+}
+
+# -----------------------------------------------------------------------------
+
 =head3 extensionRegex() - Regex zum Auffinden von Eingabe-Dateien
 
 =head4 Synopsis
@@ -575,10 +920,10 @@ sub extensionRegex {
         # deswegen filtern wir über einen Hash.
 
         my %extension;
-        for my $k (@{$self->{'baseExtensionA'}}) {
+        for my $k (@{$self->{'baseExtensionA'}}) { # Basis-Extensions
             $extension{$k}++;
         }
-        for my $plg (@{$self->{'pluginA'}}) {
+        for my $plg (@{$self->{'pluginA'}}) { # Plugin-Extensions
             $extension{$plg->extension}++;
         }        
 
@@ -599,6 +944,91 @@ sub extensionRegex {
 
 # -----------------------------------------------------------------------------
 
+=head3 findFiles() - Finde ContentProcessor-Dateien in Verzeichnis
+
+=head4 Synopsis
+
+    @files | $fileA = $cop->findFiles($dir);
+
+=head4 Arguments
+
+=over 4
+
+=item $dir
+
+Das Verzeichnis, das nach Dateien durchsucht wird
+
+=back
+
+=head4 Returns
+
+Liste der Datei-Pfade. Im Skalarkontext eine Referenz auf die
+Liste.
+
+=cut
+
+# -----------------------------------------------------------------------------
+
+sub findFiles {
+    my ($self,$dir) = @_;
+
+    my @files = Prty::Path->find($dir,
+        -type=>'f',
+        -pattern=>$self->extensionRegex,
+        -sloppy=>1,
+    );
+    
+    return wantarray? @files: \@files;
+}
+
+# -----------------------------------------------------------------------------
+
+=head3 msg() - Gib Information aus
+
+=head4 Synopsis
+
+    $cop->msg($level,$msg);
+
+=head4 Arguments
+
+=over 4
+
+=item $msg
+
+Text, der ausgegeben werden soll.
+
+=back
+
+=head4 Returns
+
+nichts
+
+=cut
+
+# -----------------------------------------------------------------------------
+
+sub msg {
+    my ($self,$level,$msg) = splice @_,0,3;
+    # @_
+
+    if ($level > $self->{'verbosity'}) {
+        # Keine Ausgabe, wenn der Meldungslevel höher ist
+        # als der vorgegebene Verbosity-Level.
+        return;
+    }
+    
+    $msg =~ s/%T/sprintf '%.3f',
+        Time::HiRes::gettimeofday-$self->get('t0')/e;
+
+    $msg =~ s/%N/Prty::Formatter->readableNumber(shift,',')/eg;
+
+    printf STDERR "$msg\n",@_;
+
+    return;
+}
+
+# -----------------------------------------------------------------------------
+
 =head3 plugin() - Ermittele Plugin zu Abschnitts-Objekt
 
 =head4 Synopsis
@@ -629,6 +1059,7 @@ Plugin-Objekt
 # -----------------------------------------------------------------------------
 
 my %Plugins; # Section-Type => Liste der Plugins
+my $Plugin;  # Universelles Plugin (es sollte höchstens eins definiert sein)
     
 sub plugin {
     my ($self,$sec) = @_;
@@ -637,7 +1068,14 @@ sub plugin {
         # Indiziere Plugins nach Section-Type
 
         for my $plg (@{$self->{'pluginA'}}) {
-            push @{$Plugins{$plg->sectionType}},$plg;
+            if (my $sectionType = $plg->sectionType) {
+                # Normales Plugin
+                push @{$Plugins{$sectionType}},$plg;
+            }
+            else {
+                # Universelles Plugin
+                $Plugin = $plg;
+            }
         }
     }
         
@@ -658,8 +1096,11 @@ sub plugin {
             }
         }
     }
-        
-    return undef; # kein passendes Plugin gefunden
+    
+    # Kein Plugin zum SectionType gefunden. Wir liefern das
+    # universelle Plugin, sofern existent, oder undef
+
+    return $Plugin? $Plugin: undef;
 }
 
 # -----------------------------------------------------------------------------
@@ -759,7 +1200,7 @@ sub stateDb {
 
 # -----------------------------------------------------------------------------
 
-=head3 storage() - Pfad zum oder innerhalb Storage
+=head3 storage() - Pfad zum oder innerhalb des Storage
 
 =head4 Synopsis
 
@@ -805,7 +1246,7 @@ sub storage {
 
 =head1 VERSION
 
-1.097
+1.098
 
 =head1 AUTHOR
 
