@@ -4,7 +4,7 @@ use base qw/Prty::Hash/;
 use strict;
 use warnings;
 
-our $VERSION = 1.097;
+our $VERSION = 1.098;
 
 # -----------------------------------------------------------------------------
 
@@ -68,7 +68,7 @@ sub generate {
     my $self = shift;
 
     if (defined(my $method = $self->method)) {
-        $self->entity->$method();
+        return $self->$method();
     }
     
     return $self->data;
@@ -78,7 +78,7 @@ sub generate {
 
 =head1 VERSION
 
-1.097
+1.098
 
 =head1 AUTHOR
 
