@@ -4,7 +4,7 @@ use base qw/Prty::Hash/;
 use strict;
 use warnings;
 
-our $VERSION = 1.097;
+our $VERSION = 1.098;
 
 use Prty::File::Video;
 use POSIX ();
@@ -853,10 +853,18 @@ Name der generierten Video-Datei.
 
 Erzeuge einen Audio-Stream aus Audio-Datei $file.
 
+=item -duration => $duration (Default: undef)
+
+Beende die Ausgabe, wenn die Dauer $duration erreicht ist.
+
 =item -framerate => $n (Default: 6)
 
 Anzahl Bilder pro/Sekunde.
 
+=item -loop => $bool (Default: 0)
+
+Wiederhole die Bildserie zyklisch.
+
 =item -play => 0|1|2 (Default: 0)
 
 Zeige das generierte Video im Player an, statt es in einer Datei
@@ -884,14 +892,18 @@ sub imagesToVideo {
     # Optionen und Argumente
 
     my $audio = undef;
+    my $duration = undef,
     my $framerate = 6;
+    my $loop = 0;
     my $play = 0;
     my $size = undef;
     my $videoFramerate = 24;
 
     Prty::Option->extract(\@_,
         -audio=>\$audio,
+        -duration=>\$duration,
         -framerate=>\$framerate,
+        -loop=>\$loop,
         -play=>\$play,
         -size=>\$size,
         -videoFramerate=>\$videoFramerate,
@@ -909,6 +921,9 @@ sub imagesToVideo {
     
     # * Input
 
+    if ($loop) {
+        $self->addOption(-loop=>$loop);
+    }
     $self->addOption(-framerate=>$framerate);
     $self->addOption(-f=>'image2');
     if ($pattern =~ /\*/) {
@@ -933,12 +948,18 @@ sub imagesToVideo {
     if ($play) {
         push @filter,$self->scaleFilter('720*a',720);
     }
-    
+
+    # ** YUV color space (laut ffmpeg-Doku aus Kompatibilitätsgründen nötig)
+    push @filter,'format=yuv420p';
+
     $self->addFilter(-vf=>\@filter,',');
 
     # * Output-Options
-    
-    if ($audio) {
+
+    if (defined $duration) {
+        $self->addOption(-t=>$duration);
+    }
+    elsif ($audio) {
         $self->addOption('-shortest');
     }
 
@@ -1456,7 +1477,7 @@ sub execute {
 
 =head1 VERSION
 
-1.097
+1.098
 
 =head1 AUTHOR
 
