@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use utf8;
 
-our $VERSION = 1.097;
+our $VERSION = 1.098;
 
 use Prty::Option;
 use Scalar::Util ();
@@ -630,7 +630,7 @@ sub unlock {
 
 =head4 Synopsis
 
-    $fh->setEncoding($encoding);
+    $fh = $fh->setEncoding($encoding);
 
 =head4 Description
 
@@ -640,6 +640,10 @@ bzw. beim Lesen dekodiert.
 
 Die Methode liefert keinen Wert zurück.
 
+=head4 Returns
+
+FileHandle-Objekt (für Method-Chaining)
+
 =cut
 
 # -----------------------------------------------------------------------------
@@ -647,7 +651,7 @@ Die Methode liefert keinen Wert zurück.
 sub setEncoding {
     my ($self,$encoding) = @_;
     $self->binmode(sprintf ':encoding(%s)',$encoding);
-    return;
+    return $self;
 }
 
 # -----------------------------------------------------------------------------
@@ -740,7 +744,7 @@ sub captureStderr {
 
 =head1 VERSION
 
-1.097
+1.098
 
 =head1 AUTHOR
 
