@@ -8,7 +8,7 @@ use strict;
 use warnings;
 use utf8;
 
-our $VERSION = 1.097;
+our $VERSION = 1.098;
 
 use Prty::Option;
 use Prty::FileHandle;
@@ -661,6 +661,11 @@ Liefere nur Dateien, die vor mindestens $seconds zuletzt geändert
 wurden. Diese Option ist z.B. nützlich, um veraltete temporäre Dateien
 zu finden, um sie zu löschen.
 
+=item -outHandle => $fh (Default: \*STDOUT)
+
+Filehandle, auf die Ausgabe im Falle von -verbose=>1 geschrieben
+werden.
+
 =item -pattern => $regex (Default: keiner)
 
 Schränke die Treffer auf jene Pfade ein, die Muster $regex erfüllen.
@@ -689,6 +694,10 @@ oder nicht.
 Liefere nur Verzeichnisse ('d') oder nur, was kein Verzeichnis ist ('f'),
 oder liefere alles (undef).
 
+=item -verbose => $bool (Default: 0)
+
+Schreibe Meldungen auf Ausgabe-Handle (s. Option -outHandle).
+
 =back
 
 =cut
@@ -705,24 +714,28 @@ sub find {
     my $decode = undef;
     my $follow = 1;
     my $olderThan = 0;
+    my $outHandle = \*STDOUT;
     my $pattern = undef;
     my $slash = 0;
     my $sloppy = 0;
     my $subPath = 0;
     my $testSub = undef;
     my $type = undef;
+    my $verbose = 0;
 
     if (@_) {
         Prty::Option->extract(\@_,
             -decode=>\$decode,
             -follow=>\$follow,
             -olderThan=>\$olderThan,
+            -outHandle=>\$outHandle,
             -pattern=>\$pattern,
             -slash=>\$slash,
             -sloppy=>\$sloppy,
             -subPath=>\$subPath,
             -testSub=>\$testSub,
             -type=>\$type,
+            -verbose=>\$verbose,
         );
     }
 
@@ -787,6 +800,10 @@ sub find {
 
         # $File::Find::name =~ s|^\./||; # ./ am Anfang entfernen
 
+        if ($verbose) {
+            print $outHandle $File::Find::name,"\n";
+        }
+
         if ($decode) {
             push @paths,Encode::decode($decode,$File::Find::name);
         }
@@ -1575,7 +1592,7 @@ sub symlinkRelative {
 
 =head1 VERSION
 
-1.097
+1.098
 
 =head1 AUTHOR
 
