@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use utf8;
 
-our $VERSION = 1.097;
+our $VERSION = 1.098;
 
 use Prty::Path;
 use Prty::Ipc;
@@ -171,7 +171,7 @@ sub new {
         file=>undef,
         exec=>undef,
         filter=>undef,
-        ln=>0,
+        ln=>undef,
         cn=>0,
         bg=>0,
         esc=>1,
@@ -214,7 +214,8 @@ sub dump {
     # @_: @args
 
     my $root = $self->rootNode;
-    my $cssPrefix = $self->rootNode->get('cssPrefix');
+    my $cssPrefix = $root->get('cssPrefix');
+    my $minLnWidth = $root->get('minLnWidth');
 
     my $text = $self->{'text'};
     my $esc = $self->{'esc'};
@@ -265,14 +266,14 @@ sub dump {
             colNumbers=>$self->{'cn'},
             cssPrefix=>"$cssPrefix-code",
             escape=>$self->{'cotedo'}, # oder doch 0? 1 wird für CoTeDo-SOURCE benötigt
-            lineNumbers=>$self->{'ln'},
+            lineNumbers=>$self->{'ln'} || 0,
             minLineNumberWidth=>$root->{'minLnWidth'},
             language=>$self->{'language'},
             source=>\$text,
         );
     }
 
-    if (my $i = $self->{'ln'}) {
+    if (my $i = $self->{'ln'} || 0) {
         my $n = $text =~ tr/\n//;
         my $l = length $n;
         if (my $minLnWidth = $root->{'minLnWidth'}) {
@@ -295,13 +296,27 @@ sub dump {
         return "CODE\n$text\n";
     }
     elsif ($h) {
-        my $class = $self->{'class'} || 'code-pre';
+        my $ln = $self->{'ln'};
+        my $class = "$cssPrefix-".($self->{'class'} || 'code-pre');
+        if ($highlight) {
+            if (!defined $ln) {
+                $ln = 1; # bei highlight Zeilennummer als Default
+            }
+
+            $class .= sprintf ' brush: %s; toolbar: false',lc $highlight;
+            if ($minLnWidth) {
+                $class .= sprintf '; pad-line-numbers: %s',$minLnWidth;
+            }
+            if (!$ln) {
+                $class .= '; gutter: false';
+            }
+        }
+
         return $h->tag('div',
-            class=>"$cssPrefix-code-div",
+            class=>$highlight && $ln? "$cssPrefix-highlight-div":
+                "$cssPrefix-code-div",
             $h->tag('pre',
-                class=>"$cssPrefix-$class"
-                    .($highlight? sprintf(" brush: %s; pad-line-numbers: 2",
-                        lc $highlight): ''),
+                class=>$class,
                 $text,
             )
         );
@@ -336,7 +351,7 @@ sub dump {
 
 =head1 VERSION
 
-1.097
+1.098
 
 =head1 AUTHOR
 
