@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use utf8;
 
-our $VERSION = 1.097;
+our $VERSION = 1.098;
 
 use Prty::Sdoc::Line;
 use Prty::Sdoc::Node;
@@ -512,7 +512,8 @@ sub dump {
 
         # my $highlightUrl = 'http://alexgorbatchev.com/pub/sh/current';
         #my $highlightUrl = '/tmp/highlight';
-        my $highlightUrl = 'http://s31tz.de/syntaxhighlighter';
+        my $highlightUrl = 'http://s31tz.de/js/syntaxhighlighter';
+        my $xregexpUrl = 'http://s31tz.de/js/xregexp';
 
         return $h->cat(
             $h->doctype,
@@ -552,7 +553,7 @@ sub dump {
                     id=>"$cssPrefix-body",
                     $frontPage.$childs.
                     $h->tag('script',
-                        src=>"$highlightUrl/src/XRegExp.js",
+                        src=>"$xregexpUrl/src/xregexp.js",
                     ).
                     $h->tag('script',
                         # src=>"$highlightUrl/scripts/shCore.js",
@@ -609,7 +610,7 @@ sub dump {
 
 =head1 VERSION
 
-1.097
+1.098
 
 =head1 AUTHOR
 
