@@ -4,12 +4,12 @@ use base qw/Prty::Hash/;
 use strict;
 use warnings;
 
-our $VERSION = 1.097;
+our $VERSION = 1.098;
 
 use Prty::Array;
 use Prty::Converter;
 use Prty::Hash;
-use Prty::Pod;
+use Prty::Pod::Generator;
 
 # -----------------------------------------------------------------------------
 
@@ -741,10 +741,10 @@ sub expand {
         if ($inlineSegments) {
             # Inline-Segmente expandieren
 
-            $val =~ s|B\{([^}]+)\}|Prty::Pod->fmt('B',$1)|gse;
-            $val =~ s|C\{([^}]+)\}|Prty::Pod->fmt('C',$1)|gse;
-            $val =~ s|E\{([^}]+)\}|Prty::Pod->fmt('I',$1)|gse;
-            $val =~ s|I\{([^}]+)\}|Prty::Pod->fmt('I',$1)|gse;
+            $val =~ s|B\{([^}]+)\}|Prty::Pod::Generator->fmt('B',$1)|gse;
+            $val =~ s|C\{([^}]+)\}|Prty::Pod::Generator->fmt('C',$1)|gse;
+            $val =~ s|E\{([^}]+)\}|Prty::Pod::Generator->fmt('I',$1)|gse;
+            $val =~ s|I\{([^}]+)\}|Prty::Pod::Generator->fmt('I',$1)|gse;
             $val =~ s|Q\{([^}]+)\}|"$1"|gs;
         }
     }
@@ -845,7 +845,7 @@ sub tableOfContents {
 
 =head1 VERSION
 
-1.097
+1.098
 
 =head1 AUTHOR
 
