@@ -4,9 +4,9 @@ use base qw/Prty::Sdoc::Node/;
 use strict;
 use warnings;
 
-our $VERSION = 1.097;
+our $VERSION = 1.098;
 
-use Prty::Pod;
+use Prty::Pod::Generator;
 
 # -----------------------------------------------------------------------------
 
@@ -140,7 +140,7 @@ sub dump {
         );
     }
     elsif ($format eq 'pod') {
-        return Prty::Pod->fmt('I',$text)."\n\n";
+        return Prty::Pod::Generator->fmt('I',$text)."\n\n";
     }
     elsif ($format eq 'man') {
         $self->notImplemented;
@@ -156,7 +156,7 @@ sub dump {
 
 =head1 VERSION
 
-1.097
+1.098
 
 =head1 AUTHOR
 
