@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use utf8;
 
-our $VERSION = 1.097;
+our $VERSION = 1.098;
 
 # -----------------------------------------------------------------------------
 
@@ -749,6 +749,48 @@ sub getRef {
 
 # -----------------------------------------------------------------------------
 
+=head3 search() - Suche Attributwert
+
+=head4 Synopsis
+
+    ($key,$val) = $sec->search(\@sections,\@keys);
+
+=head4 Description
+
+Durchsuche die Liste der Abschnitts-Objekte ($self,@sections)
+nach dem ersten Attribut aus @keys, das einen Wert besitzt und
+liefere das Schlüssel/Wert-Paar zurück. Ist der Wert 'NULL',
+wird '' (Leerstring) geliefert. Auf diese Weise kann auf "höherer Ebene"
+definierter Wert außer Kraft gesetzt werden.
+
+=cut
+
+# -----------------------------------------------------------------------------
+
+sub search {
+    my $self = shift;
+    my $sectionA = shift;
+    my $keyA = [];
+
+    my $key = '';
+    my $text = '';
+    SECTION: for my $sec ($self,@$sectionA) {
+        for (@$keyA) {
+            if ($text = $sec->get($_)) {
+                $key = $_;
+                last SECTION;
+            }
+        }
+    }
+    if ($text eq 'NULL') {
+        $text = '';
+    }
+
+    return ($key,$text);
+}
+
+# -----------------------------------------------------------------------------
+
 =head3 try() - Werte abfragen ohne Exception
 
 =head4 Synopsis
@@ -1241,7 +1283,7 @@ sub AUTOLOAD {
 
 =head1 VERSION
 
-1.097
+1.098
 
 =head1 AUTHOR
 
